==> dde-session-shell_5.5.50.orig.tar.xz: dde-session-shell-5.5.50/translations/dde-session-shell_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Arcalapú azonosítás</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Hitelesítés Arc azonosítóval</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Az Arc Azonosító zárolva, kérjük használja a jelszavát</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Az Ön ujjlenyomatának ellenőrzése</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Az ujjlenyomat zárolva, kérem használja a jelszavát</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Írisz Azonosítás</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Hitelesítés Írisz Azonosítóval</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Az Írisz Azonosító zárolva, kérjük használja a jelszavát</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Helytelen jelszó</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Kérjük próbálja újra 1 perc múlva</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Jelszó visszaállítása</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Elfelejtette a jelszavát?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Kérjük próbálja újra 1 perc múlva</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Jelszó visszaállítása</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Elfelejtette a jelszavát?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Helytelen PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey szükséges</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Adja meg a PIN kódját</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Kérjük próbálja újra 1 perc múlva</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Felhasználói fiók</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>A jelszava %n nap múlva lejár, kérjük változtassa meg időben</numerusform><numerusform>A jelszava %n nap múlva lejár, kérjük változtassa meg időben</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Jelszava lejárt, kérjük változtassa meg</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Hibás Felhasználói fiók</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Helytelen jelszó</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Képernyő zárolása</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>A képernyő zárolása sikertelen</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Ujjlenyomat azonosítás időtúllépése, kérjük adja meg a jelszót kézzel</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Ujjlenyomatok nem egyeznek</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>A fenti felhasználók be vannak jelentkezve, ami leállításkor az adatok elvesztéséhez vezethet. Biztosan le akarja állítani?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>A fenti felhasználók be vannak jelentkezve, ami újraindításkor az adatok elvesztéséhez vezethet. Biztosan újra akarja indítani?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Engedélyezte a magas rendszer biztonsági szintet, így nem tud Wayland módra váltani. Kérjük tiltsa le a magas biztonsági szintet a Biztonsági Központban, és próbálkozzon újra.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Alvó állapot</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zárolás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Felhasználóváltás</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Rendszer váltása</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Rendszermonitor indítása</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép leállítását, és a kikapcsolás kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>A program bezárásához kattintson a Mégsem gombra, majd zárja be a programot.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép újraindítását, és az újraindítás kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép alvó állapotba való lépését, és az alvó állapot kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép hibernálását, és a hibernálás kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép kijelentkezését, és a kijelentkezés kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Alvó állapot</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Biztosan le akarja állítani?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Biztosan újra akarja indítani?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Biztosan ki akar jelentkezni?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Bekapcsolás</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Kikapcsolás</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.81.orig.tar.xz: dde-session-shell-5.5.81/translations/dde-session-shell_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Arcalapú azonosítás</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Hitelesítés Arc azonosítóval</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Az Arc Azonosító zárolva, kérjük használja a jelszavát</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Az eszköz nem érhető el!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Az Ön ujjlenyomatának ellenőrzése</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Az ujjlenyomat zárolva, kérem használja a jelszavát</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Írisz Azonosítás</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Hitelesítés Írisz Azonosítóval</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Az Írisz Azonosító zárolva, kérjük használja a jelszavát</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Helytelen jelszó</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Kérjük próbálja újra 1 perc múlva</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Jelszó visszaállítása</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Elfelejtette a jelszavát?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Kérjük próbálja újra 1 perc múlva</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Jelszó visszaállítása</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Elfelejtette a jelszavát?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Helytelen PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey szükséges</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Adja meg a PIN kódját</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Kérjük próbálja újra 1 perc múlva</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Felhasználói fiók</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Jelszava lejárt, kérjük változtassa meg</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Hibás Felhasználói fiók</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Helytelen jelszó</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Képernyő zárolása</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>A képernyő zárolása sikertelen</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Ujjlenyomat azonosítás időtúllépése, kérjük adja meg a jelszót kézzel</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Ujjlenyomatok nem egyeznek</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>A fenti felhasználók be vannak jelentkezve, ami leállításkor az adatok elvesztéséhez vezethet. Biztosan le akarja állítani?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>A fenti felhasználók be vannak jelentkezve, ami újraindításkor az adatok elvesztéséhez vezethet. Biztosan újra akarja indítani?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Engedélyezte a magas rendszer biztonsági szintet, így nem tud Wayland módra váltani. Kérjük tiltsa le a magas biztonsági szintet a Biztonsági Központban, és próbálkozzon újra.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Alvó állapot</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zárolás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Felhasználóváltás</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Rendszer váltása</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Rendszermonitor indítása</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép leállítását, és a kikapcsolás kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>A program bezárásához kattintson a Mégsem gombra, majd zárja be a programot.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép újraindítását, és az újraindítás kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép alvó állapotba való lépését, és az alvó állapot kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép hibernálását, és a hibernálás kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép kijelentkezését, és a kijelentkezés kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Alvó állapot</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Biztosan le akarja állítani?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Biztosan újra akarja indítani?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Biztosan ki akar jelentkezni?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Bekapcsolás</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Kikapcsolás</translation>
    </message>
</context>
</TS>
